/*
	GraphicsModule_Types.r
	
	Resource types for writing After Dark graphics modules.
	
	These resource types are for After Dark version 2.0.
	
	For more information, consult the programmer's section of the manual.
	
	by Patrick Beard and Bruce Burkhalter
	
	Copyright 1989, 1990, Berkeley Systems, Inc.
*/
 
 
 /*
	slider control:  The value stored in the resource is the value passed in the
	sliderValues array in the GMParamBlock.  The values can range from 0 to 100
	and are controlled by the user in the AfterDark cdev.  The name of the resource
	is used as a descriptive label for the slider, and is 15 bytes (including length byte)
	maximum.  The numbering of the resources must be 1000-1003, and can be non-inclusive.
	Therefore, there can be 4 sliders total, the first numbered 1000, the second 1001,
	and so on.
	'sVal' means 'slider value.'
 */

type 'sVal' {
	integer;
};

/*
	slider control units:  This resource consists of pairs of integer values and strings
	values.  These pairs tell AfterDark to display the strings when the slider value is
	 to the integer and < the next integer.  This allows the displaying of arbitrarily
	scaled sliders.  The strings are limited to 7 bytes (including length byte) maximum.
	'sUnt' means 'slider units.'
 */
type 'sUnt' {
	integer=$$Countof(UArray);
	Array UArray {
		integer;	/* range lower limit */
		pstring;	/* text for this range */
	};
};


/*
	button control:  The value stored in the resource is the value of the message
	parameter that is passed to the graphics module upon the user's clicking.
	The name of the resource is used as the title of the button.
	'bVal' means 'button value.'
 */

type 'bVal' {
	integer;
};

/*
	menu control:	The value stored in the resource is the number of the currently 
	item in the menu control.  'mVal' means 'menu value.'
*/

type 'mVal' {
	integer;
};

/*	check box control:	The value stored in the resource is the state of the
	check button.  If the button is checked, the value is 1.  If it is not
	checked, the value is 0.  The name of the resource is used as the title of 
	the check box.  'xVal' means 'check box value.'
*/

type 'xVal' {
	integer;
};

/*	text control:	The value stored in the resource determines which
	string of a corresponding 'STR#' resource is displayed.  If the value
	is 0, no string is displayed.  If it is 1 or greater, the same numbered
	string in the 'STR#' resource is displayed.  'tval' means 'text value.'
*/

type 'tVal' {
	integer;
};

/*
	control display:  The value stored in the resource is used to display a
	specific control conditionally.  A full description of this resource is
	in the manual.  'Val' means 'mu (machine) value.'
*/

type 'Val' {
	boolean		needntHaveSoundAvailable,
				mustHaveSoundAvailable;
#undef reserved
	boolean		reserved;
	boolean		reserved;
	boolean		reserved;
	boolean		reserved;
#define reserved false	
	boolean		isRunningUnderMultiModule,
					isNotRunningUnderMultiModule;
					
	boolean		allowedToChangeColorEnvironment,
					isNotAllowedToChangeColorEnvironment;

	boolean		needntMainMonBeDimmable,
				mustMainMonBeDimmable;
				
	boolean		needntAllBeDimmable,
				mustAllBeDimmable;
				
	boolean		needntBeAllCLUTDevices,
				mustBeAllCLUTDevices;
				
	boolean		needntHaveOneCLUTDevice,
				mustHaveOneCLUTDevice;
				
	boolean		needntAllBeInColor,
				mustAllBeInColor;
				
	boolean		needntHaveOneInColor,
				mustHaveOneInColor;
				
	boolean		needntAllBeInMultiBit,
				mustAllBeInMultiBit;
				
	boolean		needntHaveOneInMultiBit,
				mustHaveOneInMultiBit;
				
	boolean		needntHaveColorQD,
				mustHaveColorQD;
};

/*
	system heap expansion:  The value stored in this resource is used to tell the
	system how much to expand the system heap by at startup time.  AfterDark will
	also read the resource and attempt to hold on to the memory by allocating a
	handle of that size and making it purgeable when loading the graphics module.
	'sysz' id 0 tells the system how much to increase the system heap by, and tells
	AfterDark how much memory the graphics module would like to have.  Id 1 tells
	AfterDark about the graphics module's absolute minimum storage requirements.
	'sysz' means 'system zone?'
 */
 
type 'sysz' {
	unsigned longint;							/* memory requirement */
};

/*
	Support for new After Dark calls resource.  'Cals' is a byte that has bits
	that correspond to the calls that the module understands.  If this resource
	doesn't exist, the original four calls (Initialize, Close, Blank, and DrawFrame)
	are assumed to be supported.
	
	After Dark looks for the 'Cals' resource with id = 0.
 */

type 'Cals' {
#undef reserved
	boolean		reserved;
	boolean		reserved;
#define reserved false	
				
	boolean		doesNotUnderstandDoAboutMessage,
				understandsDoAboutMessage;
				
	boolean		doesNotUnderstandModuleSelectedMessage,
				understandsModuleSelectedMessage;
				
	boolean		doesNotUnderstandDrawFrameMessage,
				understandsDrawFrameMessage;
				
	boolean		doesNotUnderstandBlankMessage,
				understandsBlankMessage;
				
	boolean		doesNotUnderstandCloseMessage,
				understandsCloseMessage;
				
	boolean		doesNotUnderstandCloseMessage,
				understandsInitializeMessage;
};

/*
	Support for sound resource.  The 'Chnl' resource tells After Dark what
	kind of sound channel the module wants.  The sampled sound channel is
	the only sound channel supported by MultiModule, so this is recommended
	to be the only one.  The volume setting for the module is also stored here.
	
	After Dark looks for the 'Chnl' resource with id = 0.
 */

type 'Chnl' {
	integer;	/* tells what kind of sound channel to reserve for sound use. */
	integer;	/* tells what volume we should use. */
};
